Module diagnostic

Module diagnostic 

Structured diagnostic reporting for C parse errors.

Provides rustc-style error messages with source locations, code snippets, explanatory notes, and actionable fix suggestions extracted from clang.

Structs

Diagnostic
A structured diagnostic extracted from the C parser (clang-sys).
DiagnosticError
Error wrapping one or more diagnostics from the C parser.

Enums

ErrorCategory
Category of the error for the error[category] display.
Severity
Severity level of a diagnostic.